MCPConfig class

Main configuration class for Flutter MCP

Constructors

MCPConfig({required String appName, required String appVersion, bool useBackgroundService = false, bool useNotification = false, bool useTray = false, bool secure = true, bool lifecycleManaged = true, bool autoStart = true, Level? loggingLevel, bool? enablePerformanceMonitoring, bool? enableMetricsExport, String? metricsExportPath, bool? autoLoadPlugins, List<PluginConfig>? pluginConfigurations, int? highMemoryThresholdMB, int? lowBatteryWarningThreshold, int? maxConnectionRetries, int? llmRequestTimeoutMs, BackgroundConfig? background, NotificationConfig? notification, TrayConfig? tray, List<MCPJob>? schedule, List<MCPServerConfig>? autoStartServer, List<MCPClientConfig>? autoStartClient, List<MCPLlmClientConfig>? autoStartLlmClient, List<MCPLlmServerConfig>? autoStartLlmServer, bool? autoRegisterLlmPlugins = false, bool? registerMcpPluginsWithLlm = false, bool? registerCoreLlmPlugins = false, bool? enableRetrieval = false, Map<String, dynamic>? extraOptions})
Creates a new MCP configuration

Properties

appName String
App name
final
appVersion String
App version
final
autoLoadPlugins bool?
Whether to auto load plugins
final
autoRegisterLlmPlugins bool?
Whether to automatically register LLM plugins with the flutter_mcp system
final
autoStart bool
Whether to auto start
final
autoStartClient List<MCPClientConfig>?
Auto start client configuration
final
autoStartLlmClient List<MCPLlmClientConfig>?
Auto-start LLM client configurations (new field)
final
autoStartLlmServer List<MCPLlmServerConfig>?
Auto-start LLM server configurations (new field)
final
autoStartServer List<MCPServerConfig>?
Auto start server configuration
final
background BackgroundConfig?
Background configuration
final
enableMetricsExport bool?
Whether to enable metrics export
final
enablePerformanceMonitoring bool?
Whether to enable performance monitoring
final
enableRetrieval bool?
Whether to enable retrieval capabilities
final
extraOptions Map<String, dynamic>?
Any extra configuration options
final
hashCode int
The hash code for this object.
no setterinherited
highMemoryThresholdMB int?
High memory usage threshold (MB)
final
lifecycleManaged bool
Whether to manage lifecycle
final
llmRequestTimeoutMs int?
LLM request timeout (milliseconds)
final
loggingLevel Level?
Logging level
final
lowBatteryWarningThreshold int?
Low battery warning threshold (%)
final
maxConnectionRetries int?
Connection retry limit
final
metricsExportPath String?
Metrics export path
final
notification NotificationConfig?
Notification configuration
final
pluginConfigurations List<PluginConfig>?
Plugin configurations
final
registerCoreLlmPlugins bool?
Whether to register core LLM plugins
final
registerMcpPluginsWithLlm bool?
Whether to register MCP plugins with the LLM system
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule List<MCPJob>?
Scheduled jobs
final
secure bool
Whether to use secure storage
final
tray TrayConfig?
Tray configuration
final
useBackgroundService bool
Whether to use background service
final
useNotification bool
Whether to use notifications
final
useTray bool
Whether to use tray
final

Methods

copyWith({String? appName, String? appVersion, bool? useBackgroundService, bool? useNotification, bool? useTray, bool? secure, bool? lifecycleManaged, bool? autoStart, Level? loggingLevel, bool? enablePerformanceMonitoring, bool? enableMetricsExport, String? metricsExportPath, bool? autoLoadPlugins, List<PluginConfig>? pluginConfigurations, int? highMemoryThresholdMB, int? lowBatteryWarningThreshold, int? maxConnectionRetries, int? llmRequestTimeoutMs, BackgroundConfig? background, NotificationConfig? notification, TrayConfig? tray, List<MCPJob>? schedule, List<MCPServerConfig>? autoStartServer, List<MCPClientConfig>? autoStartClient, List<MCPLlmClientConfig>? autoStartLlmClient, List<MCPLlmServerConfig>? autoStartLlmServer, bool? autoRegisterLlmPlugins, bool? registerMcpPluginsWithLlm, bool? registerCoreLlmPlugins, bool? enableRetrieval, Map<String, dynamic>? extraOptions}) MCPConfig
Creates a copy of this configuration with the specified fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this configuration to JSON map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited