MCPLlmClientConfig class

Configuration for LLM clients with explicit MCP client relationships

Constructors

MCPLlmClientConfig({required String providerName, required LlmConfiguration config, bool isDefault = false, List<String> mcpClientIds = const []})
Creates a new LLM client configuration

Properties

config LlmConfiguration
Configuration for the LLM provider
final
hashCode int
The hash code for this object.
no setterinherited
isDefault bool
Whether this client should be set as the default LLM client
final
mcpClientIds List<String>
List of MCP client references (either by index "client_0" or by name "ClientName")
final
providerName String
LLM provider name (e.g., 'openai', 'claude', 'together')
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this configuration to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited