MCPLlmServerConfig class

Configuration for LLM servers with explicit MCP server relationships

Constructors

MCPLlmServerConfig({required String providerName, required LlmConfiguration config, bool isDefault = false, List<String> mcpServerIds = const []})
Creates a new LLM server configuration

Properties

config LlmConfiguration
Configuration for the LLM provider
final
hashCode int
The hash code for this object.
no setterinherited
isDefault bool
Whether this server should be set as the default LLM server
final
mcpServerIds List<String>
List of MCP server references (either by index "server_0" or by name "ServerName")
final
providerName String
LLM provider name (e.g., 'openai', 'claude', 'together')
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this configuration to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited