BackgroundConfig class

Background service configuration

Constructors

BackgroundConfig({String? notificationChannelId, String? notificationChannelName, String? notificationDescription, String? notificationChannelDescription, String? notificationIcon, String? notificationTitle, bool enableForegroundService = false, bool wakeLock = false, bool wifiLock = false, bool autoStartOnBoot = false, int intervalMs = 5000, bool keepAlive = true})
BackgroundConfig.defaultConfig()
Create default configuration
factory

Properties

autoStartOnBoot bool
Auto start on boot
final
enableForegroundService bool
Enable foreground service (Android)
final
hashCode int
The hash code for this object.
no setterinherited
intervalMs int
Background task interval (milliseconds)
final
keepAlive bool
Keep connection alive
final
notificationChannelDescription String?
Notification channel description (Android)
final
notificationChannelId String?
Notification channel ID (Android)
final
notificationChannelName String?
Notification channel name (Android)
final
notificationDescription String?
Notification channel description (Android)
final
notificationIcon String?
Notification icon (Android)
final
notificationTitle String?
Notification title
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wakeLock bool
Wake lock (Android)
final
wifiLock bool
WiFi lock (Android)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toMap() Map<String, dynamic>
Convert to map (alias for toJson)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited