NotificationConfig class
Notification configuration
Constructors
- NotificationConfig({String? channelId, String? channelName, String? channelDescription, String? icon, bool enableSound = true, bool enableVibration = true, NotificationPriority priority = NotificationPriority.normal, bool requestPermissionOnInit = true, String? defaultIcon})
Properties
- channelDescription → String?
-
Notification channel description (Android)
final
- channelId → String?
-
Notification channel ID (Android)
final
- channelName → String?
-
Notification channel name (Android)
final
- defaultIcon → String?
-
Default notification icon
final
- enableSound → bool
-
Whether to enable notification sound
final
- enableVibration → bool
-
Whether to enable notification vibration
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
Notification icon
final
- priority → NotificationPriority
-
Notification priority
final
- requestPermissionOnInit → bool
-
Whether to request permission on initialization
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON
-
toMap(
) → Map< String, dynamic> - Convert to Map (for platform channel)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultConfig(
) → NotificationConfig - Default configuration